/*

  Capacitive Touch Sensor Module - MPR121

  Parts required:
  - Arduino Board
  - Capacitive Touch Sensor Module - MPR121

  Library:
  - Adafruit_MPR121

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 1 Apr 2020
  Version : v1.0

  Modulet kan købes på www.arduinotech.dk

*/

#include <Wire.h>                                                                       // include library Wire.h
#include "Adafruit_MPR121.h"                                                            // include library Adafruit_MPR121.h
                
#define _BV(bit) (1 << (bit))

Adafruit_MPR121 cap = Adafruit_MPR121();                                                // create object cap from library Adafruit_MPR121     

int lasttouched = 0;
int currtouched = 0;
int buzzerPin = 3;                                                                      // set buzzer to digital port 3
int toneDuration = 500;                                                                 // time to play tone
int toneArray[12] = {523, 587, 659, 698, 784, 880, 988, 1047, 1175, 1319, 1397, 1568};  // tone notes

void setup() {
  cap.begin(0x5A);                                                                      // start object cap on I2C port 0x5A
}

void loop() {
  currtouched = cap.touched();                                                          // read cap.touched for the current touch sensor pressed and store in currtouched

  for (int i = 0; i < 12; i++) {                                                        // for i = 0 to 12 do
    if ((currtouched & _BV(i)) && !(lasttouched & _BV(i)) ) {

      tone(buzzerPin, toneArray[i], toneDuration);                                      // play tone
      delay(100);                                                                       // wait 100ms
    }
  }

  lasttouched = currtouched;                                                            // reset touch state
}
